auth

package
v0.0.0-...-873d3b2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 7, 2026 License: MIT Imports: 17 Imported by: 0

Documentation

Index

Constants

const CloudEmailPrompt = "Atlassian account email"

CloudEmailPrompt is the prompt shown when asking for the Atlassian account email.

const CloudTokenPrompt = "API token"

CloudTokenPrompt is the prompt shown when asking for the API token.

const CloudTokenURL = "https://id.atlassian.com/manage-profile/security/api-tokens"

CloudTokenURL is the URL where users create Bitbucket Cloud API tokens.

Variables

This section is empty.

Functions

func NewCmdAuth

func NewCmdAuth(f *cmdutil.Factory) *cobra.Command

NewCmdAuth returns the root auth command.

Types

This section is empty.

Jump to