prompter

package
v0.0.0-...-873d3b2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 7, 2026 License: MIT Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Interface

type Interface interface {
	Input(prompt, defaultValue string) (string, error)
	Password(prompt string) (string, error)
	Confirm(prompt string, defaultYes bool) (bool, error)
}

Interface exposes interactive prompt helpers used by commands.

func New

func New(ios *iostreams.IOStreams) Interface

New creates a prompter bound to the provided IO streams. When prompts are not possible (stdin not a TTY) the helper returns errors so commands can fallback to non-interactive flows.

Jump to